pub struct AppSession { /* private fields */ }Expand description
App-level session that layers VT Code features on top of the core session.
Implementations
Sourceimpl AppSession
impl AppSession
pub fn handle_event( &mut self, event: CrosstermEvent, events: &UnboundedSender<InlineEvent>, callback: Option<&(dyn Fn(&InlineEvent) + Send + Sync + 'static)>, )
Sourceimpl AppSession
impl AppSession
pub fn new( theme: InlineTheme, placeholder: Option<String>, view_rows: u16, ) -> Self
pub fn core(&self) -> &CoreSessionState
pub fn core_mut(&mut self) -> &mut CoreSessionState
pub fn handle_command(&mut self, command: InlineCommand)
Methods from Deref<Target = CoreSessionState>
pub fn header_chain_values(&self) -> Vec<String>
pub fn handle_command(&mut self, command: InlineCommand)
Sourcepub fn history_position(&self) -> Option<(usize, usize)>
pub fn history_position(&self) -> Option<(usize, usize)>
Returns the current history position for status bar display Returns (current_index, total_entries) or None if not navigating history